@@ -6,7 +6,7 @@ def getFileContent(path):
         lines = []
         file.close()
         for line in content:
-            lines.append(line.replace("\n", ""))
+            lines.append(line.replace("\n", "").replace("\r", ""))
         return lines
 
 def getLineFromFile(path, line):
@@ -69,10 +69,8 @@ def createFile(path):
     file.close()
 
 def createDirectory(path):
-    try:
-        os.mkdir(path)
-    except:
-        pass
+    try: os.makedirs(path)
+    except:pass
 
 def clearFile(path):
     file = open(path, "w")
